/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p jobviewiface /usr/src/ports/kf5-kjobwidgets/kf5-kjobwidgets-5.43.0-1.x86_64/src/kjobwidgets-5.43.0/src/org.kde.JobView.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#include "jobviewiface.h"

/*
 * Implementation of interface class OrgKdeJobViewV2Interface
 */

OrgKdeJobViewV2Interface::OrgKdeJobViewV2Interface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent)
    : QDBusAbstractInterface(service, path, staticInterfaceName(), connection, parent)
{
}

OrgKdeJobViewV2Interface::~OrgKdeJobViewV2Interface()
{
}


#include "jobviewiface.moc"
