/****************************************************************************
** Meta object code from reading C++ file 'kwidgetjobtracker_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kjobwidgets-5.43.0/src/kwidgetjobtracker_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwidgetjobtracker_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget_t {
    QByteArrayData data[27];
    char stringdata0[314];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget_t qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget = {
    {
QT_MOC_LITERAL(0, 0, 42), // "KWidgetJobTracker::Private::P..."
QT_MOC_LITERAL(1, 43, 11), // "infoMessage"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 5), // "plain"
QT_MOC_LITERAL(4, 62, 4), // "rich"
QT_MOC_LITERAL(5, 67, 11), // "description"
QT_MOC_LITERAL(6, 79, 5), // "title"
QT_MOC_LITERAL(7, 85, 22), // "QPair<QString,QString>"
QT_MOC_LITERAL(8, 108, 6), // "field1"
QT_MOC_LITERAL(9, 115, 6), // "field2"
QT_MOC_LITERAL(10, 122, 11), // "totalAmount"
QT_MOC_LITERAL(11, 134, 10), // "KJob::Unit"
QT_MOC_LITERAL(12, 145, 4), // "unit"
QT_MOC_LITERAL(13, 150, 6), // "amount"
QT_MOC_LITERAL(14, 157, 15), // "processedAmount"
QT_MOC_LITERAL(15, 173, 7), // "percent"
QT_MOC_LITERAL(16, 181, 5), // "speed"
QT_MOC_LITERAL(17, 187, 5), // "value"
QT_MOC_LITERAL(18, 193, 9), // "slotClean"
QT_MOC_LITERAL(19, 203, 9), // "suspended"
QT_MOC_LITERAL(20, 213, 7), // "resumed"
QT_MOC_LITERAL(21, 221, 18), // "_k_keepOpenToggled"
QT_MOC_LITERAL(22, 240, 11), // "_k_openFile"
QT_MOC_LITERAL(23, 252, 15), // "_k_openLocation"
QT_MOC_LITERAL(24, 268, 21), // "_k_pauseResumeClicked"
QT_MOC_LITERAL(25, 290, 7), // "_k_stop"
QT_MOC_LITERAL(26, 298, 15) // "_k_arrowToggled"

    },
    "KWidgetJobTracker::Private::ProgressWidget\0"
    "infoMessage\0\0plain\0rich\0description\0"
    "title\0QPair<QString,QString>\0field1\0"
    "field2\0totalAmount\0KJob::Unit\0unit\0"
    "amount\0processedAmount\0percent\0speed\0"
    "value\0slotClean\0suspended\0resumed\0"
    "_k_keepOpenToggled\0_k_openFile\0"
    "_k_openLocation\0_k_pauseResumeClicked\0"
    "_k_stop\0_k_arrowToggled"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KWidgetJobTracker__Private__ProgressWidget[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      15,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   89,    2, 0x0a /* Public */,
       5,    3,   94,    2, 0x0a /* Public */,
      10,    2,  101,    2, 0x0a /* Public */,
      14,    2,  106,    2, 0x0a /* Public */,
      15,    1,  111,    2, 0x0a /* Public */,
      16,    1,  114,    2, 0x0a /* Public */,
      18,    0,  117,    2, 0x0a /* Public */,
      19,    0,  118,    2, 0x0a /* Public */,
      20,    0,  119,    2, 0x0a /* Public */,
      21,    1,  120,    2, 0x08 /* Private */,
      22,    0,  123,    2, 0x08 /* Private */,
      23,    0,  124,    2, 0x08 /* Private */,
      24,    0,  125,    2, 0x08 /* Private */,
      25,    0,  126,    2, 0x08 /* Private */,
      26,    0,  127,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    3,    4,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 7, 0x80000000 | 7,    6,    8,    9,
    QMetaType::Void, 0x80000000 | 11, QMetaType::ULongLong,   12,   13,
    QMetaType::Void, 0x80000000 | 11, QMetaType::ULongLong,   12,   13,
    QMetaType::Void, QMetaType::ULong,   15,
    QMetaType::Void, QMetaType::ULong,   17,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void KWidgetJobTracker::Private::ProgressWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ProgressWidget *_t = static_cast<ProgressWidget *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->infoMessage((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 1: _t->description((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QPair<QString,QString>(*)>(_a[2])),(*reinterpret_cast< const QPair<QString,QString>(*)>(_a[3]))); break;
        case 2: _t->totalAmount((*reinterpret_cast< KJob::Unit(*)>(_a[1])),(*reinterpret_cast< qulonglong(*)>(_a[2]))); break;
        case 3: _t->processedAmount((*reinterpret_cast< KJob::Unit(*)>(_a[1])),(*reinterpret_cast< qulonglong(*)>(_a[2]))); break;
        case 4: _t->percent((*reinterpret_cast< ulong(*)>(_a[1]))); break;
        case 5: _t->speed((*reinterpret_cast< ulong(*)>(_a[1]))); break;
        case 6: _t->slotClean(); break;
        case 7: _t->suspended(); break;
        case 8: _t->resumed(); break;
        case 9: _t->_k_keepOpenToggled((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->_k_openFile(); break;
        case 11: _t->_k_openLocation(); break;
        case 12: _t->_k_pauseResumeClicked(); break;
        case 13: _t->_k_stop(); break;
        case 14: _t->_k_arrowToggled(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob::Unit >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob::Unit >(); break;
            }
            break;
        }
    }
}

const QMetaObject KWidgetJobTracker::Private::ProgressWidget::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget.data,
      qt_meta_data_KWidgetJobTracker__Private__ProgressWidget,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KWidgetJobTracker::Private::ProgressWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWidgetJobTracker::Private::ProgressWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KWidgetJobTracker__Private__ProgressWidget.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KWidgetJobTracker::Private::ProgressWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
