/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -m -p jobviewserverinterface /usr/src/ports/kf5-kjobwidgets/kf5-kjobwidgets-5.43.0-1.x86_64/src/kjobwidgets-5.43.0/src/org.kde.JobViewServer.xml
 *
 * qdbusxml2cpp is Copyright (C) 2017 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef JOBVIEWSERVERINTERFACE_H
#define JOBVIEWSERVERINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.JobViewServer
 */
class OrgKdeJobViewServerInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.JobViewServer"; }

public:
    OrgKdeJobViewServerInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeJobViewServerInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QDBusObjectPath> requestView(const QString &appName, const QString &appIconName, int capabilities)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(appName) << QVariant::fromValue(appIconName) << QVariant::fromValue(capabilities);
        return asyncCallWithArgumentList(QStringLiteral("requestView"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace kde {
    typedef ::OrgKdeJobViewServerInterface JobViewServer;
  }
}
#endif
