/****************************************************************************
** Meta object code from reading C++ file 'kabstractwidgetjobtracker.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kjobwidgets-5.43.0/src/kabstractwidgetjobtracker.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kabstractwidgetjobtracker.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KAbstractWidgetJobTracker_t {
    QByteArrayData data[14];
    char stringdata0[137];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KAbstractWidgetJobTracker_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KAbstractWidgetJobTracker_t qt_meta_stringdata_KAbstractWidgetJobTracker = {
    {
QT_MOC_LITERAL(0, 0, 25), // "KAbstractWidgetJobTracker"
QT_MOC_LITERAL(1, 26, 7), // "stopped"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 5), // "KJob*"
QT_MOC_LITERAL(4, 41, 3), // "job"
QT_MOC_LITERAL(5, 45, 7), // "suspend"
QT_MOC_LITERAL(6, 53, 6), // "resume"
QT_MOC_LITERAL(7, 60, 11), // "registerJob"
QT_MOC_LITERAL(8, 72, 13), // "unregisterJob"
QT_MOC_LITERAL(9, 86, 8), // "finished"
QT_MOC_LITERAL(10, 95, 8), // "slotStop"
QT_MOC_LITERAL(11, 104, 11), // "slotSuspend"
QT_MOC_LITERAL(12, 116, 10), // "slotResume"
QT_MOC_LITERAL(13, 127, 9) // "slotClean"

    },
    "KAbstractWidgetJobTracker\0stopped\0\0"
    "KJob*\0job\0suspend\0resume\0registerJob\0"
    "unregisterJob\0finished\0slotStop\0"
    "slotSuspend\0slotResume\0slotClean"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KAbstractWidgetJobTracker[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   64,    2, 0x06 /* Public */,
       5,    1,   67,    2, 0x06 /* Public */,
       6,    1,   70,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    1,   73,    2, 0x0a /* Public */,
       8,    1,   76,    2, 0x0a /* Public */,
       9,    1,   79,    2, 0x09 /* Protected */,
      10,    1,   82,    2, 0x09 /* Protected */,
      11,    1,   85,    2, 0x09 /* Protected */,
      12,    1,   88,    2, 0x09 /* Protected */,
      13,    1,   91,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KAbstractWidgetJobTracker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KAbstractWidgetJobTracker *_t = static_cast<KAbstractWidgetJobTracker *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->stopped((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 1: _t->suspend((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 2: _t->resume((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 3: _t->registerJob((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 4: _t->unregisterJob((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 5: _t->finished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 6: _t->slotStop((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 7: _t->slotSuspend((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 8: _t->slotResume((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 9: _t->slotClean((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KJob* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (KAbstractWidgetJobTracker::*_t)(KJob * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAbstractWidgetJobTracker::stopped)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (KAbstractWidgetJobTracker::*_t)(KJob * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAbstractWidgetJobTracker::suspend)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (KAbstractWidgetJobTracker::*_t)(KJob * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&KAbstractWidgetJobTracker::resume)) {
                *result = 2;
                return;
            }
        }
    }
}

const QMetaObject KAbstractWidgetJobTracker::staticMetaObject = {
    { &KJobTrackerInterface::staticMetaObject, qt_meta_stringdata_KAbstractWidgetJobTracker.data,
      qt_meta_data_KAbstractWidgetJobTracker,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KAbstractWidgetJobTracker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAbstractWidgetJobTracker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KAbstractWidgetJobTracker.stringdata0))
        return static_cast<void*>(this);
    return KJobTrackerInterface::qt_metacast(_clname);
}

int KAbstractWidgetJobTracker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KJobTrackerInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KAbstractWidgetJobTracker::stopped(KJob * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KAbstractWidgetJobTracker::suspend(KJob * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void KAbstractWidgetJobTracker::resume(KJob * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
